@@ -66,6 +66,8 @@ Later updates (from the source web site):
 
 =item * version 0.89, published on August 28, 2006
 
+=item * version 0.91, published on September 11, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -109,3 +111,4 @@ lou mister_serdecisions sandeep
 patty smokin_jim betty_the_bulldozer
 amber_dextrous stinky_pete 
 phil_o_dendron
+steve
