@@ -36,6 +36,8 @@ Further updates:
 
 =item * version 0.90, published on September 4, 2006
 
+=item * version 0.91, published on September 11, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -1499,6 +1501,7 @@ EGYPTUS
 EHARTNETT
 EHERSHEY
 EHOOD
+EIDOLON
 EIJABB
 EIKEG
 EILARA
@@ -2285,6 +2288,7 @@ JDUNCAN
 JDUTTON
 JEAANDER
 JEAGLE
+JEALLEN
 JEAN
 JEB
 JEDWARDS
@@ -2885,6 +2889,7 @@ KWITTMER
 KWMAK
 KWOO
 KWOOLERY
+KXJ
 KYANNY
 KYLED
 KYNAN
@@ -4021,6 +4026,7 @@ PWD
 PWIRDEMO
 PWO
 PYTHIAN
+QIU
 QJZHOU
 QMACRO
 QMIC
@@ -4503,6 +4509,7 @@ SGP
 SGRANTZ
 SHADEJON
 SHADINGER
+SHADOVV
 SHADOW
 SHADOWX
 SHANCOCK
@@ -4811,6 +4818,7 @@ SUNTONG
 SUPAPLEX
 SUPCIK
 SURESHG
+SURESHRAM
 SUTCH
 SVANZOEST
 SVENBAUM
@@ -5207,6 +5215,7 @@ WAYNEM
 WAZZUTEKE
 WBAKER
 WBNIV
+WBY
 WCATLAN
 WCOTTAY
 WDH
@@ -5267,6 +5276,7 @@ WOLF
 WONKO
 WOODY
 WORENKD
+WORM
 WORRALL
 WPMOORE
 WPS
